/*Copyright (c) 2022, Nexperia
*All rights reserved.
*
*Redistribution and use in source and binary forms, with or without modification, 
*are permitted provided that the following conditions are met:
*
*1. Redistributions of source code must retain the above copyright notice, 
*this list of conditions and the following disclaimer.
*
*2. Redistributions in binary form must reproduce the above copyright 
*notice, this list of conditions and the following disclaimer in the 
*documentation and/or other materials provided with the distribution.
*
*3. Neither the name of the copyright holder nor the names of its contributors 
*may be used to endorse or promote products derived from this software without 
*specific prior written permission.
*
*THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY 
*EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
*OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT 
*SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED 
*TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR 
*BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
*CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//Evaluation board codecode that uses the Serial Prompt of Arduino IDE to program NCA9555 EVB RevA
//This code is used to sequentially flash LEDs back and forth -- like Night Rider.
//Uses Arduino UNO, go to Tools -> Board to change board type.
//Go to Tools -> Serial Port and select correct Port that Arduino is connected to. This information can be found through Device Manager.
//Go to Tools -> Serial Monitor, this will open monitor for PORT 0 readback
//Reset Arduino after uloading code
//  Date   :  Nov 01, 2022
//  Version:  1.00
//  File   :  NCA95xx_demo.ino
#include <Wire.h>

const int deviceaddress = 0x27;
const int inputP0 = 0x00;
const int inputP1 = 0x01;
const int outputP0 = 0x02;
const int outputP1 = 0x03;
const int INVP0 = 0x04;
const int INVP1 = 0x05;
const int ConfigP0 = 0x06;
const int ConfigP1 = 0x07;
byte RegRead = 0;
byte CRead = 0;
int WriteIt = 1;
int Up = 1;
int Delay = 150;

void setup() {
  Wire.begin();                // join i2c bus (address optional for master)
  Serial.begin(9600);          // start serial communication at 9600bps

  pinMode(A0, INPUT);
  //pinMode(A0, INPUT_PULLUP);
  pinMode(A1, INPUT);
  //pinMode(A1, INPUT_PULLUP);
  pinMode(A2, INPUT);
  //pinMode(A2, INPUT_PULLUP);

}

void loop() {

  write8(deviceaddress, ConfigP0, 0xFF);//set PORT0 as inputs
  write8(deviceaddress, outputP0, 0x00);//Set Output port to 0
  RegRead = read8(deviceaddress, inputP0);
  Serial.println(RegRead, HEX);  // read PORT0
  CRead = RegRead & 0b10000000;
  //Serial.println(CRead, HEX);  // print the reading
  if (CRead == 0) {
    Delay = 50;
  } else {
    Delay = 150;
  }


  write8(deviceaddress, ConfigP1, 0x00);//set PORT1 as outputs
  write8(deviceaddress, outputP1, WriteIt);//write to PORT1

  if (Up == 1) {
    WriteIt = WriteIt << 1;
  } else {
    WriteIt = WriteIt >> 1;
  }

  if (WriteIt > 128) {
    Up = 0;
    WriteIt = 64;
  } else if (WriteIt < 1) {
    Up = 1;
    WriteIt = 2;
  }

  delay(Delay);                  // wait a bit since people have to read the output :)



}


void write8(int SRegister, int Address, int Data) {
  Wire.beginTransmission(SRegister);
  Wire.write(Address);
  Wire.write(Data);
  Wire.endTransmission();
}

byte read8(int SRegister, int Address) {
  byte ReadD = 0;
  Wire.beginTransmission(SRegister);
  Wire.write(Address);
  Wire.endTransmission();
  Wire.requestFrom(SRegister, 1);
  Wire.endTransmission();
  ReadD = Wire.read();
  return ReadD;
}
